options

package
v0.3.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 2, 2024 License: Apache-2.0 Imports: 16 Imported by: 0

Documentation

Index

Constants

const (
	MaskString = "******"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type CoreOptions added in v0.3.2

type CoreOptions struct {
	ReadOnlyMode bool
}

func NewCoreOptions added in v0.3.2

func NewCoreOptions() *CoreOptions

func (*CoreOptions) AddFlags added in v0.3.2

func (o *CoreOptions) AddFlags(fs *pflag.FlagSet)

AddFlags adds flags for a specific Option to the specified FlagSet

func (*CoreOptions) ApplyTo added in v0.3.2

func (o *CoreOptions) ApplyTo(config *registry.ExtraConfig) error

func (*CoreOptions) Validate added in v0.3.2

func (o *CoreOptions) Validate() []error

type ElasticSearchConfig

type ElasticSearchConfig struct {
	Addresses []string
	Username  string
	Password  string
}

type RecommendedOptions added in v0.1.5

type RecommendedOptions struct {
	ServerRun     *options.ServerRunOptions
	Etcd          *options.EtcdOptions
	SecureServing *options.SecureServingOptionsWithLoopback
	Audit         *options.AuditOptions
	Features      *options.FeatureOptions

	// FeatureGate is a way to plumb feature gate through if you have them.
	FeatureGate featuregate.FeatureGate
	// ExtraAdmissionInitializers is called once after all ApplyTo from the options above, to pass the returned
	// admission plugin initializers to Admission.ApplyTo.
	ExtraAdmissionInitializers func(c *server.RecommendedConfig) ([]admission.PluginInitializer, error)
	Admission                  *options.AdmissionOptions
	// API Server Egress Selector is used to control outbound traffic from the API Server
	EgressSelector *options.EgressSelectorOptions
	// Traces contains options to control distributed request tracing.
	Traces *options.TracingOptions
}

RecommendedOptions contains the recommended options for running an API server. If you add something to this list, it should be in a logical grouping. Each of them can be nil to leave the feature unconfigured on ApplyTo.

func NewRecommendedOptions added in v0.1.5

func NewRecommendedOptions(prefix string, codec runtime.Codec) *RecommendedOptions

func (*RecommendedOptions) AddFlags added in v0.1.5

func (o *RecommendedOptions) AddFlags(fs *pflag.FlagSet)

func (*RecommendedOptions) ApplyTo added in v0.1.5

func (o *RecommendedOptions) ApplyTo(config *server.RecommendedConfig) error

ApplyTo adds RecommendedOptions to the server configuration. pluginInitializers can be empty, it is only need for additional initializers.

func (*RecommendedOptions) Validate added in v0.1.5

func (o *RecommendedOptions) Validate() []error

type SearchStorageOptions

type SearchStorageOptions struct {
	SearchStorageType      string
	ElasticSearchAddresses []string
	ElasticSearchUsername  string
	ElasticSearchPassword  string
}

func NewSearchStorageOptions

func NewSearchStorageOptions() *SearchStorageOptions

func (*SearchStorageOptions) AddFlags

func (o *SearchStorageOptions) AddFlags(fs *pflag.FlagSet)

AddFlags adds flags for a specific Option to the specified FlagSet

func (*SearchStorageOptions) ApplyTo

func (o *SearchStorageOptions) ApplyTo(config *registry.ExtraConfig) error

func (SearchStorageOptions) MarshalJSON added in v0.3.2

func (o SearchStorageOptions) MarshalJSON() ([]byte, error)

MarshalJSON is custom marshalling function for masking sensitive field values

func (*SearchStorageOptions) Validate

func (o *SearchStorageOptions) Validate() []error

Jump to