apiserver

package
v0.2.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 12, 2023 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CompletedConfig

type CompletedConfig struct {
	GenericConfig genericapiserver.CompletedConfig
	ExtraConfig   *registry.ExtraConfig
}

func (*CompletedConfig) New

func (c *CompletedConfig) New() (*KarbourServer, error)

New returns a new instance of APIServer from the given config.

type Config

type Config struct {
	GenericConfig *genericapiserver.RecommendedConfig
	ExtraConfig   *registry.ExtraConfig
}

Config defines the config for the apiserver

func (*Config) Complete

func (cfg *Config) Complete() *CompletedConfig

Complete fills in any fields not set that are required to have valid data. It's mutating the receiver.

type KarbourServer added in v0.2.4

type KarbourServer struct {
	*genericapiserver.GenericAPIServer
	// contains filtered or unexported fields
}

KarbourServer is the carrier of the main process of Karbour.

func (*KarbourServer) Error added in v0.2.4

func (s *KarbourServer) Error() error

Error returns any errors that have occurred during the setup of the KarbourServer. It is designed to be called after the configuration steps to ensure any issues are captured and reported.

func (*KarbourServer) InstallCoreServer added in v0.2.4

func (s *KarbourServer) InstallCoreServer(c *CompletedConfig) *KarbourServer

InstallCoreServer installs the core server (handling non kubernetes-like API, regular HTTP requests) onto the KarbourServer. This is typically the server that serves the user interface assets.

func (*KarbourServer) InstallGatewayServer added in v0.2.4

func (s *KarbourServer) InstallGatewayServer(c *CompletedConfig) *KarbourServer

InstallGatewayServer installs various resource-specific REST storage implementations on the KarbourServer. This method is part of the bootstrapping process of setting up the API server.

func (*KarbourServer) InstallStaticFileServer added in v0.2.4

func (s *KarbourServer) InstallStaticFileServer() *KarbourServer

InstallStaticFileServer sets up the server to serve static files. It is used to serve files like stylesheets, scripts, and images for the karbour dashboard.

Jump to