Documentation
¶
Index ¶
Constants ¶
const SuccessMessage = "OK"
SuccessMessage is the default success message for successful responses.
Variables ¶
This section is empty.
Functions ¶
func FailureResponse ¶
FailureResponse creates a response renderer for a failed request.
Types ¶
type Duration ¶
Duration is a custom type that represents a duration of time.
func (Duration) MarshalJSON ¶
MarshalJSON customizes JSON representation of the Duration type.
Click to show internal directories.
Click to hide internal directories.