server

package
v0.3.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 12, 2024 License: Apache-2.0 Imports: 32 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ConfigRegister added in v0.3.7

func ConfigRegister(hookContext genericapiserver.PostStartHookContext) error

Types

type CompletedConfig

type CompletedConfig struct {
	GenericConfig genericapiserver.CompletedConfig
	ExtraConfig   *registry.ExtraConfig
}

func (*CompletedConfig) New

func (c *CompletedConfig) New() (*KarbourServer, error)

New returns a new instance of APIServer from the given config.

type Config

type Config struct {
	GenericConfig *genericapiserver.RecommendedConfig
	ExtraConfig   *registry.ExtraConfig
}

Config defines the config for the apiserver

func (*Config) Complete

func (cfg *Config) Complete() *CompletedConfig

Complete fills in any fields not set that are required to have valid data. It's mutating the receiver.

type KarbourServer

type KarbourServer struct {
	*genericapiserver.GenericAPIServer
	// contains filtered or unexported fields
}

KarbourServer is the carrier of the main process of Karbour.

func (*KarbourServer) Error

func (s *KarbourServer) Error() error

Error returns any errors that have occurred during the setup of the KarbourServer. It is designed to be called after the configuration steps to ensure any issues are captured and reported.

func (*KarbourServer) InstallAPIs added in v0.3.5

func (s *KarbourServer) InstallAPIs(apiResourceConfigSource serverstorage.APIResourceConfigSource, restOptionsGetter generic.RESTOptionsGetter, restStorageProviders ...registry.RESTStorageProvider) error

func (*KarbourServer) InstallCoreServer

func (s *KarbourServer) InstallCoreServer(c *CompletedConfig) *KarbourServer

InstallCoreServer installs the core server (handling non kubernetes-like API, regular HTTP requests) onto the KarbourServer. This is typically the server that serves the user interface assets.

func (*KarbourServer) InstallKubernetesServer

func (s *KarbourServer) InstallKubernetesServer(c *CompletedConfig) *KarbourServer

InstallKubernetesServer installs various resource-specific REST storage implementations on the KarbourServer. This method is part of the bootstrapping process of setting up the API server.

func (*KarbourServer) InstallLegacyAPI added in v0.3.5

func (s *KarbourServer) InstallLegacyAPI(restOptionsGetter generic.RESTOptionsGetter) error

func (*KarbourServer) InstallStaticFileServer

func (s *KarbourServer) InstallStaticFileServer() *KarbourServer

InstallStaticFileServer sets up the server to serve static files. It is used to serve files like stylesheets, scripts, and images for the karbour dashboard.

Jump to