proxy

package
v0.2.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 6, 2023 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	ClusterProxyURL = "/apis/cluster.karbour.com/v1beta1/clusters/%s/proxy/"
)

Variables

This section is empty.

Functions

func ClusterFrom

func ClusterFrom(ctx context.Context) (string, bool)

ClusterFrom returns the value of the cluster key on the ctx

func WithCluster

func WithCluster(parent context.Context, cluster string) context.Context

WithCluster returns a context that describes the nested cluster context

func WithProxyByCluster

func WithProxyByCluster(handler http.Handler) http.Handler

Types

This section is empty.

Jump to