apiserver

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 15, 2023 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

const DefaultStaticDirectory = "./static"

DefaultStaticDirectory is the default static directory for dashboard.

Variables

This section is empty.

Functions

This section is empty.

Types

type APIServer

type APIServer struct {
	GenericAPIServer *genericapiserver.GenericAPIServer
}

APIServer contains state for a Kubernetes cluster master/api server.

type CompletedConfig

type CompletedConfig struct {
	// contains filtered or unexported fields
}

CompletedConfig embeds a private pointer that cannot be instantiated outside of this package.

func (CompletedConfig) New

func (c CompletedConfig) New() (*APIServer, error)

New returns a new instance of APIServer from the given config.

type Config

type Config struct {
	GenericConfig *genericapiserver.RecommendedConfig
	ExtraConfig   *ExtraConfig
}

Config defines the config for the apiserver

func (*Config) Complete

func (cfg *Config) Complete() CompletedConfig

Complete fills in any fields not set that are required to have valid data. It's mutating the receiver.

type ExtraConfig

type ExtraConfig struct {
	SearchStorageType      string
	ElasticSearchAddresses []string
	ElasticSearchName      string
	ElasticSearchPassword  string
}

ExtraConfig holds custom apiserver config

Jump to