resource

package
v0.2.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 12, 2023 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Resource

type Resource struct {
	Name       string
	Namespace  string
	APIVersion string
	Kind       string
	Cluster    string
}

type ResourceConfig

type ResourceConfig struct {
	Verbose bool `json:"verbose"`
}

type ResourceManager

type ResourceManager struct {
	// contains filtered or unexported fields
}

func NewResourceManager

func NewResourceManager(config *ResourceConfig) *ResourceManager

NewResourceManager returns a new ResourceManager

func (*ResourceManager) ConvertResourceGraphToMap

func (*ResourceManager) GetResource

GetCluster returns the unstructured cluster object for a given cluster

func (*ResourceManager) GetResourceRelationship

GetResourceRelationship returns a full graph that contains all the resources that are related to obj

func (*ResourceManager) GetTopologyForResource

func (c *ResourceManager) GetTopologyForResource(ctx context.Context, client *multicluster.MultiClusterClient, res *Resource) (map[string]ResourceTopology, error)

GetTopologyForCluster returns a map that describes topology for a given cluster

func (*ResourceManager) GetYAMLForResource

func (c *ResourceManager) GetYAMLForResource(ctx context.Context, client *multicluster.MultiClusterClient, res *Resource) ([]byte, error)

GetYAMLForCluster returns the yaml byte array for a given cluster

type ResourceTopology

type ResourceTopology struct {
	Identifier string
	Parents    []string
	Children   []string
}

Jump to